pub fn should_collect_region_watermark_from_query_ctx(
query_ctx: &QueryContextRef,
) -> Result<bool>Expand description
Returns whether terminal region watermark metrics should be collected for the query context.
pub fn should_collect_region_watermark_from_query_ctx(
query_ctx: &QueryContextRef,
) -> Result<bool>Returns whether terminal region watermark metrics should be collected for the query context.